diff --git a/docs/source/pythonapi/examples/multi-group-cross-sections.ipynb b/docs/source/pythonapi/examples/multi-group-cross-sections.ipynb
index 09a48a727..70fdbfe11 100644
--- a/docs/source/pythonapi/examples/multi-group-cross-sections.ipynb
+++ b/docs/source/pythonapi/examples/multi-group-cross-sections.ipynb
@@ -287,7 +287,7 @@
"cell_type": "markdown",
"metadata": {},
"source": [
- "We can now use the fine and coarse `EnergyGroups` objects, along with our previously created materials and geometry, to instantiate some `MultiGroupXS` objects from the `openmc.mgxs` module. In particular, the following are subclasses of generic and abstract `MultiGroupXS` class:\n",
+ "We can now use the fine and coarse `EnergyGroups` objects, along with our previously created materials and geometry, to instantiate some `MGXS` objects from the `openmc.mgxs` module. In particular, the following are subclasses of generic and abstract `MGXS` class:\n",
"\n",
"* `TotalXS`\n",
"* `TransportXS`\n",
@@ -323,7 +323,7 @@
"cell_type": "markdown",
"metadata": {},
"source": [
- "Next, we must instruct our multi-group cross section objects to generate the tallies needed to calculate each of them in OpenMC. This can be done with the `MultiGroupXS.create_tallies()` routine."
+ "Next, we must instruct our multi-group cross section objects to generate the tallies needed to calculate each of them in OpenMC. This can be done with the `MGXS.create_tallies()` routine."
]
},
{
@@ -437,7 +437,7 @@
},
{
"cell_type": "code",
- "execution_count": 15,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -463,7 +463,7 @@
" License: http://mit-crpg.github.io/openmc/license.html\n",
" Version: 0.7.0\n",
" Git SHA1: 23535afa1c69644bb299bde18a094c3b99d53ae0\n",
- " Date/Time: 2015-10-08 16:26:35\n",
+ " Date/Time: 2015-10-08 19:25:10\n",
" MPI Processes: 1\n",
"\n",
" ===========================================================================\n",
@@ -533,55 +533,8 @@
" 42/1 1.11114 1.16491 +/- 0.00529\n",
" 43/1 1.14227 1.16423 +/- 0.00517\n",
" 44/1 1.14104 1.16355 +/- 0.00506\n",
- " 45/1 1.16756 1.16366 +/- 0.00492\n",
- " 46/1 1.13065 1.16274 +/- 0.00487\n",
- " 47/1 1.11251 1.16139 +/- 0.00492\n",
- " 48/1 1.14731 1.16101 +/- 0.00481\n",
- " 49/1 1.16691 1.16117 +/- 0.00469\n",
- " 50/1 1.19679 1.16206 +/- 0.00465\n",
- " Creating state point statepoint.50.h5...\n",
- "\n",
- " ===========================================================================\n",
- " ======================> SIMULATION FINISHED <======================\n",
- " ===========================================================================\n",
- "\n",
- "\n",
- " =======================> TIMING STATISTICS <=======================\n",
- "\n",
- " Total time for initialization = 3.9300E-01 seconds\n",
- " Reading cross sections = 9.0000E-02 seconds\n",
- " Total time in simulation = 1.2399E+01 seconds\n",
- " Time in transport only = 1.2391E+01 seconds\n",
- " Time in inactive batches = 1.8730E+00 seconds\n",
- " Time in active batches = 1.0526E+01 seconds\n",
- " Time synchronizing fission bank = 1.0000E-03 seconds\n",
- " Sampling source sites = 0.0000E+00 seconds\n",
- " SEND/RECV source sites = 0.0000E+00 seconds\n",
- " Time accumulating tallies = 0.0000E+00 seconds\n",
- " Total time for finalization = 2.0000E-03 seconds\n",
- " Total time elapsed = 1.2802E+01 seconds\n",
- " Calculation Rate (inactive) = 13347.6 neutrons/second\n",
- " Calculation Rate (active) = 9500.28 neutrons/second\n",
- "\n",
- " ============================> RESULTS <============================\n",
- "\n",
- " k-effective (Collision) = 1.16131 +/- 0.00453\n",
- " k-effective (Track-length) = 1.16206 +/- 0.00465\n",
- " k-effective (Absorption) = 1.16096 +/- 0.00364\n",
- " Combined k-effective = 1.16120 +/- 0.00325\n",
- " Leakage Fraction = 0.00000 +/- 0.00000\n",
- "\n"
+ " 45/1 1.16756 1.16366 +/- 0.00492\n"
]
- },
- {
- "data": {
- "text/plain": [
- "0"
- ]
- },
- "execution_count": 15,
- "metadata": {},
- "output_type": "execute_result"
}
],
"source": [
@@ -606,7 +559,7 @@
},
{
"cell_type": "code",
- "execution_count": 16,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -625,7 +578,7 @@
},
{
"cell_type": "code",
- "execution_count": 17,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -645,13 +598,13 @@
},
{
"cell_type": "code",
- "execution_count": 18,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
"outputs": [],
"source": [
- "# Load the tallies from the statepoint into each MultiGroupXS object\n",
+ "# Load the tallies from the statepoint into each MGXS object\n",
"transport.load_from_statepoint(sp)\n",
"nufission.load_from_statepoint(sp)\n",
"nuscatter.load_from_statepoint(sp)\n",
@@ -667,19 +620,11 @@
},
{
"cell_type": "code",
- "execution_count": 19,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stderr",
- "output_type": "stream",
- "text": [
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/tallies.py:1486: RuntimeWarning: invalid value encountered in divide\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"transport.compute_xs()\n",
"nufission.compute_xs()\n",
@@ -710,34 +655,11 @@
},
{
"cell_type": "code",
- "execution_count": 20,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "Multi-Group XS\n",
- "\tReaction Type =\tnu-fission\n",
- "\tDomain Type =\tcell\n",
- "\tDomain ID =\t1\n",
- "\tCross Sections [cm^-1]:\n",
- " Group 1 [0.821 - 20.0 MeV]:\t1.11e-02 +/- 7.69e-01%\n",
- " Group 2 [0.00553 - 0.821 MeV]:\t6.59e-04 +/- 2.97e-01%\n",
- " Group 3 [4e-06 - 0.00553 MeV]:\t8.95e-03 +/- 5.12e-01%\n",
- " Group 4 [6.25e-07 - 4e-06 MeV]:\t1.45e-02 +/- 7.10e-01%\n",
- " Group 5 [2.8e-07 - 6.25e-07 MeV]:\t4.71e-02 +/- 1.02e+00%\n",
- " Group 6 [1.4e-07 - 2.8e-07 MeV]:\t7.29e-02 +/- 8.86e-01%\n",
- " Group 7 [5.8e-08 - 1.4e-07 MeV]:\t1.11e-01 +/- 6.67e-01%\n",
- " Group 8 [0.0 - 5.8e-08 MeV]:\t2.38e-01 +/- 7.71e-01%\n",
- "\n",
- "\n",
- "\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"nufission.print_xs()"
]
@@ -751,141 +673,11 @@
},
{
"cell_type": "code",
- "execution_count": 21,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "data": {
- "text/html": [
- "
\n",
- "
\n",
- " \n",
- " \n",
- " | \n",
- " cell | \n",
- " group in | \n",
- " group out | \n",
- " nuclide | \n",
- " mean | \n",
- " std. dev. | \n",
- "
\n",
- " \n",
- " \n",
- " \n",
- " | 63 | \n",
- " 1 | \n",
- " 1 | \n",
- " 1 | \n",
- " total | \n",
- " 0.076970 | \n",
- " 0.001012 | \n",
- "
\n",
- " \n",
- " | 62 | \n",
- " 1 | \n",
- " 1 | \n",
- " 2 | \n",
- " total | \n",
- " 0.087876 | \n",
- " 0.000344 | \n",
- "
\n",
- " \n",
- " | 61 | \n",
- " 1 | \n",
- " 1 | \n",
- " 3 | \n",
- " total | \n",
- " 0.000418 | \n",
- " 0.000023 | \n",
- "
\n",
- " \n",
- " | 60 | \n",
- " 1 | \n",
- " 1 | \n",
- " 4 | \n",
- " total | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 59 | \n",
- " 1 | \n",
- " 1 | \n",
- " 5 | \n",
- " total | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 58 | \n",
- " 1 | \n",
- " 1 | \n",
- " 6 | \n",
- " total | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 57 | \n",
- " 1 | \n",
- " 1 | \n",
- " 7 | \n",
- " total | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 56 | \n",
- " 1 | \n",
- " 1 | \n",
- " 8 | \n",
- " total | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 55 | \n",
- " 1 | \n",
- " 2 | \n",
- " 1 | \n",
- " total | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 54 | \n",
- " 1 | \n",
- " 2 | \n",
- " 2 | \n",
- " total | \n",
- " 0.266499 | \n",
- " 0.001265 | \n",
- "
\n",
- " \n",
- "
\n",
- "
"
- ],
- "text/plain": [
- " cell group in group out nuclide mean std. dev.\n",
- "63 1 1 1 total 0.076970 0.001012\n",
- "62 1 1 2 total 0.087876 0.000344\n",
- "61 1 1 3 total 0.000418 0.000023\n",
- "60 1 1 4 total 0.000000 0.000000\n",
- "59 1 1 5 total 0.000000 0.000000\n",
- "58 1 1 6 total 0.000000 0.000000\n",
- "57 1 1 7 total 0.000000 0.000000\n",
- "56 1 1 8 total 0.000000 0.000000\n",
- "55 1 2 1 total 0.000000 0.000000\n",
- "54 1 2 2 total 0.266499 0.001265"
- ]
- },
- "execution_count": 21,
- "metadata": {},
- "output_type": "execute_result"
- }
- ],
+ "outputs": [],
"source": [
"df = nuscatter.get_pandas_dataframe()\n",
"df.head(10)"
@@ -900,7 +692,7 @@
},
{
"cell_type": "code",
- "execution_count": 22,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -918,7 +710,7 @@
},
{
"cell_type": "code",
- "execution_count": 23,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -946,24 +738,11 @@
},
{
"cell_type": "code",
- "execution_count": 24,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stderr",
- "output_type": "stream",
- "text": [
- "/usr/lib/pymodules/python2.7/matplotlib/__init__.py:1173: UserWarning: This call to matplotlib.use() has no effect\n",
- "because the backend has already been chosen;\n",
- "matplotlib.use() must be called *before* pylab, matplotlib.pyplot,\n",
- "or matplotlib.backends is imported for the first time.\n",
- "\n",
- " warnings.warn(_use_error_msg)\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Import OpenMOC and the OpenMOC/OpenCG compatibility module\n",
"import openmoc\n",
@@ -985,7 +764,7 @@
},
{
"cell_type": "code",
- "execution_count": 25,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -1019,148 +798,11 @@
},
{
"cell_type": "code",
- "execution_count": 26,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "[ NORMAL ] Ray tracing for track segmentation...\n",
- "[ NORMAL ] Dumping tracks to file...\n",
- "[ NORMAL ] Computing the eigenvalue...\n",
- "[ NORMAL ] Iteration 0:\tk_eff = 0.685185\tres = 0.000E+00\n",
- "[ NORMAL ] Iteration 1:\tk_eff = 0.785642\tres = 3.148E-01\n",
- "[ NORMAL ] Iteration 2:\tk_eff = 0.750185\tres = 1.466E-01\n",
- "[ NORMAL ] Iteration 3:\tk_eff = 0.728847\tres = 4.513E-02\n",
- "[ NORMAL ] Iteration 4:\tk_eff = 0.695633\tres = 2.844E-02\n",
- "[ NORMAL ] Iteration 5:\tk_eff = 0.663357\tres = 4.557E-02\n",
- "[ NORMAL ] Iteration 6:\tk_eff = 0.632339\tres = 4.640E-02\n",
- "[ NORMAL ] Iteration 7:\tk_eff = 0.604187\tres = 4.676E-02\n",
- "[ NORMAL ] Iteration 8:\tk_eff = 0.579451\tres = 4.452E-02\n",
- "[ NORMAL ] Iteration 9:\tk_eff = 0.558474\tres = 4.094E-02\n",
- "[ NORMAL ] Iteration 10:\tk_eff = 0.541436\tres = 3.620E-02\n",
- "[ NORMAL ] Iteration 11:\tk_eff = 0.528380\tres = 3.051E-02\n",
- "[ NORMAL ] Iteration 12:\tk_eff = 0.519273\tres = 2.411E-02\n",
- "[ NORMAL ] Iteration 13:\tk_eff = 0.513991\tres = 1.724E-02\n",
- "[ NORMAL ] Iteration 14:\tk_eff = 0.512364\tres = 1.017E-02\n",
- "[ NORMAL ] Iteration 15:\tk_eff = 0.514171\tres = 3.165E-03\n",
- "[ NORMAL ] Iteration 16:\tk_eff = 0.519155\tres = 3.527E-03\n",
- "[ NORMAL ] Iteration 17:\tk_eff = 0.527038\tres = 9.693E-03\n",
- "[ NORMAL ] Iteration 18:\tk_eff = 0.537524\tres = 1.518E-02\n",
- "[ NORMAL ] Iteration 19:\tk_eff = 0.550310\tres = 1.990E-02\n",
- "[ NORMAL ] Iteration 20:\tk_eff = 0.565096\tres = 2.379E-02\n",
- "[ NORMAL ] Iteration 21:\tk_eff = 0.581585\tres = 2.687E-02\n",
- "[ NORMAL ] Iteration 22:\tk_eff = 0.599493\tres = 2.918E-02\n",
- "[ NORMAL ] Iteration 23:\tk_eff = 0.618548\tres = 3.079E-02\n",
- "[ NORMAL ] Iteration 24:\tk_eff = 0.638497\tres = 3.179E-02\n",
- "[ NORMAL ] Iteration 25:\tk_eff = 0.659105\tres = 3.225E-02\n",
- "[ NORMAL ] Iteration 26:\tk_eff = 0.680156\tres = 3.228E-02\n",
- "[ NORMAL ] Iteration 27:\tk_eff = 0.701456\tres = 3.194E-02\n",
- "[ NORMAL ] Iteration 28:\tk_eff = 0.722831\tres = 3.132E-02\n",
- "[ NORMAL ] Iteration 29:\tk_eff = 0.744127\tres = 3.047E-02\n",
- "[ NORMAL ] Iteration 30:\tk_eff = 0.765209\tres = 2.946E-02\n",
- "[ NORMAL ] Iteration 31:\tk_eff = 0.785961\tres = 2.833E-02\n",
- "[ NORMAL ] Iteration 32:\tk_eff = 0.806283\tres = 2.712E-02\n",
- "[ NORMAL ] Iteration 33:\tk_eff = 0.826093\tres = 2.586E-02\n",
- "[ NORMAL ] Iteration 34:\tk_eff = 0.845324\tres = 2.457E-02\n",
- "[ NORMAL ] Iteration 35:\tk_eff = 0.863921\tres = 2.328E-02\n",
- "[ NORMAL ] Iteration 36:\tk_eff = 0.881841\tres = 2.200E-02\n",
- "[ NORMAL ] Iteration 37:\tk_eff = 0.899055\tres = 2.074E-02\n",
- "[ NORMAL ] Iteration 38:\tk_eff = 0.915540\tres = 1.952E-02\n",
- "[ NORMAL ] Iteration 39:\tk_eff = 0.931284\tres = 1.834E-02\n",
- "[ NORMAL ] Iteration 40:\tk_eff = 0.946283\tres = 1.720E-02\n",
- "[ NORMAL ] Iteration 41:\tk_eff = 0.960536\tres = 1.610E-02\n",
- "[ NORMAL ] Iteration 42:\tk_eff = 0.974052\tres = 1.506E-02\n",
- "[ NORMAL ] Iteration 43:\tk_eff = 0.986841\tres = 1.407E-02\n",
- "[ NORMAL ] Iteration 44:\tk_eff = 0.998920\tres = 1.313E-02\n",
- "[ NORMAL ] Iteration 45:\tk_eff = 1.010307\tres = 1.224E-02\n",
- "[ NORMAL ] Iteration 46:\tk_eff = 1.021023\tres = 1.140E-02\n",
- "[ NORMAL ] Iteration 47:\tk_eff = 1.031091\tres = 1.061E-02\n",
- "[ NORMAL ] Iteration 48:\tk_eff = 1.040537\tres = 9.861E-03\n",
- "[ NORMAL ] Iteration 49:\tk_eff = 1.049386\tres = 9.161E-03\n",
- "[ NORMAL ] Iteration 50:\tk_eff = 1.057664\tres = 8.504E-03\n",
- "[ NORMAL ] Iteration 51:\tk_eff = 1.065399\tres = 7.889E-03\n",
- "[ NORMAL ] Iteration 52:\tk_eff = 1.072617\tres = 7.313E-03\n",
- "[ NORMAL ] Iteration 53:\tk_eff = 1.079345\tres = 6.775E-03\n",
- "[ NORMAL ] Iteration 54:\tk_eff = 1.085609\tres = 6.273E-03\n",
- "[ NORMAL ] Iteration 55:\tk_eff = 1.091436\tres = 5.804E-03\n",
- "[ NORMAL ] Iteration 56:\tk_eff = 1.096851\tres = 5.367E-03\n",
- "[ NORMAL ] Iteration 57:\tk_eff = 1.101877\tres = 4.961E-03\n",
- "[ NORMAL ] Iteration 58:\tk_eff = 1.106540\tres = 4.583E-03\n",
- "[ NORMAL ] Iteration 59:\tk_eff = 1.110860\tres = 4.231E-03\n",
- "[ NORMAL ] Iteration 60:\tk_eff = 1.114861\tres = 3.905E-03\n",
- "[ NORMAL ] Iteration 61:\tk_eff = 1.118563\tres = 3.602E-03\n",
- "[ NORMAL ] Iteration 62:\tk_eff = 1.121986\tres = 3.321E-03\n",
- "[ NORMAL ] Iteration 63:\tk_eff = 1.125149\tres = 3.060E-03\n",
- "[ NORMAL ] Iteration 64:\tk_eff = 1.128069\tres = 2.819E-03\n",
- "[ NORMAL ] Iteration 65:\tk_eff = 1.130764\tres = 2.595E-03\n",
- "[ NORMAL ] Iteration 66:\tk_eff = 1.133248\tres = 2.389E-03\n",
- "[ NORMAL ] Iteration 67:\tk_eff = 1.135538\tres = 2.197E-03\n",
- "[ NORMAL ] Iteration 68:\tk_eff = 1.137648\tres = 2.021E-03\n",
- "[ NORMAL ] Iteration 69:\tk_eff = 1.139590\tres = 1.858E-03\n",
- "[ NORMAL ] Iteration 70:\tk_eff = 1.141377\tres = 1.707E-03\n",
- "[ NORMAL ] Iteration 71:\tk_eff = 1.143021\tres = 1.568E-03\n",
- "[ NORMAL ] Iteration 72:\tk_eff = 1.144531\tres = 1.440E-03\n",
- "[ NORMAL ] Iteration 73:\tk_eff = 1.145920\tres = 1.322E-03\n",
- "[ NORMAL ] Iteration 74:\tk_eff = 1.147195\tres = 1.213E-03\n",
- "[ NORMAL ] Iteration 75:\tk_eff = 1.148365\tres = 1.113E-03\n",
- "[ NORMAL ] Iteration 76:\tk_eff = 1.149440\tres = 1.020E-03\n",
- "[ NORMAL ] Iteration 77:\tk_eff = 1.150425\tres = 9.356E-04\n",
- "[ NORMAL ] Iteration 78:\tk_eff = 1.151329\tres = 8.574E-04\n",
- "[ NORMAL ] Iteration 79:\tk_eff = 1.152157\tres = 7.856E-04\n",
- "[ NORMAL ] Iteration 80:\tk_eff = 1.152916\tres = 7.196E-04\n",
- "[ NORMAL ] Iteration 81:\tk_eff = 1.153612\tres = 6.590E-04\n",
- "[ NORMAL ] Iteration 82:\tk_eff = 1.154249\tres = 6.033E-04\n",
- "[ NORMAL ] Iteration 83:\tk_eff = 1.154832\tres = 5.522E-04\n",
- "[ NORMAL ] Iteration 84:\tk_eff = 1.155366\tres = 5.053E-04\n",
- "[ NORMAL ] Iteration 85:\tk_eff = 1.155855\tres = 4.623E-04\n",
- "[ NORMAL ] Iteration 86:\tk_eff = 1.156302\tres = 4.229E-04\n",
- "[ NORMAL ] Iteration 87:\tk_eff = 1.156710\tres = 3.866E-04\n",
- "[ NORMAL ] Iteration 88:\tk_eff = 1.157084\tres = 3.535E-04\n",
- "[ NORMAL ] Iteration 89:\tk_eff = 1.157426\tres = 3.230E-04\n",
- "[ NORMAL ] Iteration 90:\tk_eff = 1.157738\tres = 2.952E-04\n",
- "[ NORMAL ] Iteration 91:\tk_eff = 1.158023\tres = 2.697E-04\n",
- "[ NORMAL ] Iteration 92:\tk_eff = 1.158284\tres = 2.464E-04\n",
- "[ NORMAL ] Iteration 93:\tk_eff = 1.158522\tres = 2.251E-04\n",
- "[ NORMAL ] Iteration 94:\tk_eff = 1.158739\tres = 2.055E-04\n",
- "[ NORMAL ] Iteration 95:\tk_eff = 1.158937\tres = 1.876E-04\n",
- "[ NORMAL ] Iteration 96:\tk_eff = 1.159119\tres = 1.713E-04\n",
- "[ NORMAL ] Iteration 97:\tk_eff = 1.159284\tres = 1.564E-04\n",
- "[ NORMAL ] Iteration 98:\tk_eff = 1.159435\tres = 1.428E-04\n",
- "[ NORMAL ] Iteration 99:\tk_eff = 1.159573\tres = 1.301E-04\n",
- "[ NORMAL ] Iteration 100:\tk_eff = 1.159699\tres = 1.188E-04\n",
- "[ NORMAL ] Iteration 101:\tk_eff = 1.159813\tres = 1.083E-04\n",
- "[ NORMAL ] Iteration 102:\tk_eff = 1.159917\tres = 9.880E-05\n",
- "[ NORMAL ] Iteration 103:\tk_eff = 1.160013\tres = 9.009E-05\n",
- "[ NORMAL ] Iteration 104:\tk_eff = 1.160100\tres = 8.222E-05\n",
- "[ NORMAL ] Iteration 105:\tk_eff = 1.160179\tres = 7.487E-05\n",
- "[ NORMAL ] Iteration 106:\tk_eff = 1.160251\tres = 6.824E-05\n",
- "[ NORMAL ] Iteration 107:\tk_eff = 1.160317\tres = 6.223E-05\n",
- "[ NORMAL ] Iteration 108:\tk_eff = 1.160376\tres = 5.675E-05\n",
- "[ NORMAL ] Iteration 109:\tk_eff = 1.160431\tres = 5.174E-05\n",
- "[ NORMAL ] Iteration 110:\tk_eff = 1.160481\tres = 4.715E-05\n",
- "[ NORMAL ] Iteration 111:\tk_eff = 1.160527\tres = 4.298E-05\n",
- "[ NORMAL ] Iteration 112:\tk_eff = 1.160568\tres = 3.910E-05\n",
- "[ NORMAL ] Iteration 113:\tk_eff = 1.160605\tres = 3.561E-05\n",
- "[ NORMAL ] Iteration 114:\tk_eff = 1.160640\tres = 3.242E-05\n",
- "[ NORMAL ] Iteration 115:\tk_eff = 1.160671\tres = 2.960E-05\n",
- "[ NORMAL ] Iteration 116:\tk_eff = 1.160699\tres = 2.689E-05\n",
- "[ NORMAL ] Iteration 117:\tk_eff = 1.160725\tres = 2.452E-05\n",
- "[ NORMAL ] Iteration 118:\tk_eff = 1.160749\tres = 2.232E-05\n",
- "[ NORMAL ] Iteration 119:\tk_eff = 1.160770\tres = 2.034E-05\n",
- "[ NORMAL ] Iteration 120:\tk_eff = 1.160790\tres = 1.855E-05\n",
- "[ NORMAL ] Iteration 121:\tk_eff = 1.160807\tres = 1.687E-05\n",
- "[ NORMAL ] Iteration 122:\tk_eff = 1.160824\tres = 1.538E-05\n",
- "[ NORMAL ] Iteration 123:\tk_eff = 1.160838\tres = 1.399E-05\n",
- "[ NORMAL ] Iteration 124:\tk_eff = 1.160852\tres = 1.280E-05\n",
- "[ NORMAL ] Iteration 125:\tk_eff = 1.160864\tres = 1.149E-05\n",
- "[ NORMAL ] Iteration 126:\tk_eff = 1.160875\tres = 1.061E-05\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Generate tracks for OpenMOC\n",
"openmoc_geometry.initializeFlatSourceRegions()\n",
@@ -1181,21 +823,11 @@
},
{
"cell_type": "code",
- "execution_count": 27,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "openmc keff = 1.161200\n",
- "openmoc keff = 1.160875\n",
- "bias [pcm]: -32.5\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Print report of keff and bias with OpenMC\n",
"openmoc_keff = solver.getKeff()\n",
@@ -1244,7 +876,7 @@
},
{
"cell_type": "code",
- "execution_count": 28,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -1278,7 +910,7 @@
},
{
"cell_type": "code",
- "execution_count": 29,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -1304,7 +936,7 @@
},
{
"cell_type": "code",
- "execution_count": 30,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -1333,22 +965,11 @@
},
{
"cell_type": "code",
- "execution_count": 31,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stderr",
- "output_type": "stream",
- "text": [
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Create a Universe to encapsulate a fuel pin\n",
"pin_cell_universe = openmc.Universe(name='1.6% Fuel Pin')\n",
@@ -1382,22 +1003,11 @@
},
{
"cell_type": "code",
- "execution_count": 32,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stderr",
- "output_type": "stream",
- "text": [
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/universe.py:223: DeprecationWarning: Cell.add_surface(...) has been deprecated and may be removed in a future version. The region for a Cell should be defined using the region property directly.\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Create root Cell\n",
"root_cell = openmc.Cell(name='root cell')\n",
@@ -1423,7 +1033,7 @@
},
{
"cell_type": "code",
- "execution_count": 33,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -1450,7 +1060,7 @@
},
{
"cell_type": "code",
- "execution_count": 34,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -1480,7 +1090,7 @@
},
{
"cell_type": "code",
- "execution_count": 35,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -1520,22 +1130,11 @@
},
{
"cell_type": "code",
- "execution_count": 36,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "data": {
- "text/plain": [
- "0"
- ]
- },
- "execution_count": 36,
- "metadata": {},
- "output_type": "execute_result"
- }
- ],
+ "outputs": [],
"source": [
"# Delete old HDF5 files\n",
"!rm *.h5\n",
@@ -1561,7 +1160,7 @@
},
{
"cell_type": "code",
- "execution_count": 37,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -1582,7 +1181,7 @@
},
{
"cell_type": "code",
- "execution_count": 38,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -1618,46 +1217,11 @@
},
{
"cell_type": "code",
- "execution_count": 39,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "Multi-Group XS\n",
- "\tReaction Type =\tnu-fission\n",
- "\tDomain Type =\tcell\n",
- "\tDomain ID =\t10000\n",
- "\tNuclide =\tU-235\n",
- "\tCross Sections [barns]:\n",
- " Group 1 [0.821 - 20.0 MeV]:\t3.30e+00 +/- 5.91e-01%\n",
- " Group 2 [0.00553 - 0.821 MeV]:\t3.97e+00 +/- 4.03e-01%\n",
- " Group 3 [4e-06 - 0.00553 MeV]:\t5.48e+01 +/- 5.56e-01%\n",
- " Group 4 [6.25e-07 - 4e-06 MeV]:\t8.84e+01 +/- 8.48e-01%\n",
- " Group 5 [2.8e-07 - 6.25e-07 MeV]:\t2.89e+02 +/- 1.25e+00%\n",
- " Group 6 [1.4e-07 - 2.8e-07 MeV]:\t4.49e+02 +/- 1.09e+00%\n",
- " Group 7 [5.8e-08 - 1.4e-07 MeV]:\t6.87e+02 +/- 7.98e-01%\n",
- " Group 8 [0.0 - 5.8e-08 MeV]:\t1.44e+03 +/- 5.73e-01%\n",
- "\n",
- "\tNuclide =\tU-238\n",
- "\tCross Sections [barns]:\n",
- " Group 1 [0.821 - 20.0 MeV]:\t1.06e+00 +/- 6.74e-01%\n",
- " Group 2 [0.00553 - 0.821 MeV]:\t1.22e-03 +/- 8.28e-01%\n",
- " Group 3 [4e-06 - 0.00553 MeV]:\t4.75e-04 +/- 7.97e+00%\n",
- " Group 4 [6.25e-07 - 4e-06 MeV]:\t6.53e-06 +/- 7.56e-01%\n",
- " Group 5 [2.8e-07 - 6.25e-07 MeV]:\t1.07e-05 +/- 1.22e+00%\n",
- " Group 6 [1.4e-07 - 2.8e-07 MeV]:\t1.55e-05 +/- 1.09e+00%\n",
- " Group 7 [5.8e-08 - 1.4e-07 MeV]:\t2.30e-05 +/- 7.97e-01%\n",
- " Group 8 [0.0 - 5.8e-08 MeV]:\t4.25e-05 +/- 5.72e-01%\n",
- "\n",
- "\n",
- "\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"nufission = xs_library[fuel_cell.id]['nu-fission']\n",
"nufission.print_xs(xs_type='micro', nuclides=['U-235', 'U-238'])"
@@ -1672,34 +1236,11 @@
},
{
"cell_type": "code",
- "execution_count": 40,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "Multi-Group XS\n",
- "\tReaction Type =\tnu-fission\n",
- "\tDomain Type =\tcell\n",
- "\tDomain ID =\t10000\n",
- "\tCross Sections [cm^-1]:\n",
- " Group 1 [0.821 - 20.0 MeV]:\t2.52e-02 +/- 6.42e-01%\n",
- " Group 2 [0.00553 - 0.821 MeV]:\t1.52e-03 +/- 3.96e-01%\n",
- " Group 3 [4e-06 - 0.00553 MeV]:\t2.06e-02 +/- 5.56e-01%\n",
- " Group 4 [6.25e-07 - 4e-06 MeV]:\t3.32e-02 +/- 8.48e-01%\n",
- " Group 5 [2.8e-07 - 6.25e-07 MeV]:\t1.09e-01 +/- 1.25e+00%\n",
- " Group 6 [1.4e-07 - 2.8e-07 MeV]:\t1.69e-01 +/- 1.09e+00%\n",
- " Group 7 [5.8e-08 - 1.4e-07 MeV]:\t2.58e-01 +/- 7.98e-01%\n",
- " Group 8 [0.0 - 5.8e-08 MeV]:\t5.41e-01 +/- 5.73e-01%\n",
- "\n",
- "\n",
- "\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"nufission = xs_library[fuel_cell.id]['nu-fission']\n",
"nufission.print_xs(xs_type='macro', nuclides='sum')"
@@ -1714,141 +1255,11 @@
},
{
"cell_type": "code",
- "execution_count": 41,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "data": {
- "text/html": [
- "\n",
- "
\n",
- " \n",
- " \n",
- " | \n",
- " cell | \n",
- " group in | \n",
- " group out | \n",
- " nuclide | \n",
- " mean | \n",
- " std. dev. | \n",
- "
\n",
- " \n",
- " \n",
- " \n",
- " | 126 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 1 | \n",
- " O-16 | \n",
- " 1.560098 | \n",
- " 0.017801 | \n",
- "
\n",
- " \n",
- " | 127 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 1 | \n",
- " H-1 | \n",
- " 0.234877 | \n",
- " 0.010096 | \n",
- "
\n",
- " \n",
- " | 124 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 2 | \n",
- " O-16 | \n",
- " 0.288236 | \n",
- " 0.004397 | \n",
- "
\n",
- " \n",
- " | 125 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 2 | \n",
- " H-1 | \n",
- " 1.587815 | \n",
- " 0.007847 | \n",
- "
\n",
- " \n",
- " | 122 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 3 | \n",
- " O-16 | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 123 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 3 | \n",
- " H-1 | \n",
- " 0.010122 | \n",
- " 0.000513 | \n",
- "
\n",
- " \n",
- " | 120 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 4 | \n",
- " O-16 | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 121 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 4 | \n",
- " H-1 | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 118 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 5 | \n",
- " O-16 | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- " | 119 | \n",
- " 10002 | \n",
- " 1 | \n",
- " 5 | \n",
- " H-1 | \n",
- " 0.000000 | \n",
- " 0.000000 | \n",
- "
\n",
- " \n",
- "
\n",
- "
"
- ],
- "text/plain": [
- " cell group in group out nuclide mean std. dev.\n",
- "126 10002 1 1 O-16 1.560098 0.017801\n",
- "127 10002 1 1 H-1 0.234877 0.010096\n",
- "124 10002 1 2 O-16 0.288236 0.004397\n",
- "125 10002 1 2 H-1 1.587815 0.007847\n",
- "122 10002 1 3 O-16 0.000000 0.000000\n",
- "123 10002 1 3 H-1 0.010122 0.000513\n",
- "120 10002 1 4 O-16 0.000000 0.000000\n",
- "121 10002 1 4 H-1 0.000000 0.000000\n",
- "118 10002 1 5 O-16 0.000000 0.000000\n",
- "119 10002 1 5 H-1 0.000000 0.000000"
- ]
- },
- "execution_count": 41,
- "metadata": {},
- "output_type": "execute_result"
- }
- ],
+ "outputs": [],
"source": [
"nuscatter = xs_library[moderator_cell.id]['nu-scatter']\n",
"df = nuscatter.get_pandas_dataframe(xs_type='micro')\n",
@@ -1864,7 +1275,7 @@
},
{
"cell_type": "code",
- "execution_count": 42,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -1892,22 +1303,11 @@
},
{
"cell_type": "code",
- "execution_count": 43,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "data": {
- "image/png": "iVBORw0KGgoAAAANSUhEUgAAAWYAAADDCAYAAACxgLv/AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\ned7lsJ91IAAAAABJRU5ErkJggg==\n",
- "text/plain": [
- ""
- ]
- },
- "metadata": {},
- "output_type": "display_data"
- }
- ],
+ "outputs": [],
"source": [
"# Create plot of the H-1 scattering matrix\n",
"fig = plt.subplot(121)\n",
@@ -1932,7 +1332,7 @@
},
{
"cell_type": "code",
- "execution_count": 44,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -1954,133 +1354,22 @@
},
{
"cell_type": "code",
- "execution_count": 45,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "Multi-Group XS\n",
- "\tReaction Type =\ttransport\n",
- "\tDomain Type =\tcell\n",
- "\tDomain ID =\t10000\n",
- "\tNuclide =\tU-238\n",
- "\tCross Sections [cm^-1]:\n",
- " Group 1 [6.25e-07 - 20.0 MeV]:\t2.17e-01 +/- 4.04e-01%\n",
- " Group 2 [0.0 - 6.25e-07 MeV]:\t2.53e-01 +/- 5.85e-01%\n",
- "\n",
- "\tNuclide =\tO-16\n",
- "\tCross Sections [cm^-1]:\n",
- " Group 1 [6.25e-07 - 20.0 MeV]:\t1.45e-01 +/- 4.10e-01%\n",
- " Group 2 [0.0 - 6.25e-07 MeV]:\t1.75e-01 +/- 6.46e-01%\n",
- "\n",
- "\tNuclide =\tU-235\n",
- "\tCross Sections [cm^-1]:\n",
- " Group 1 [6.25e-07 - 20.0 MeV]:\t7.91e-03 +/- 1.22e+00%\n",
- " Group 2 [0.0 - 6.25e-07 MeV]:\t1.82e-01 +/- 4.98e-01%\n",
- "\n",
- "\n",
- "\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"condense_xs.print_xs()"
]
},
{
"cell_type": "code",
- "execution_count": 46,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "data": {
- "text/html": [
- "\n",
- "
\n",
- " \n",
- " \n",
- " | \n",
- " cell | \n",
- " group in | \n",
- " nuclide | \n",
- " mean | \n",
- " std. dev. | \n",
- "
\n",
- " \n",
- " \n",
- " \n",
- " | 3 | \n",
- " 10000 | \n",
- " 1 | \n",
- " U-238 | \n",
- " 9.589323 | \n",
- " 0.038756 | \n",
- "
\n",
- " \n",
- " | 4 | \n",
- " 10000 | \n",
- " 1 | \n",
- " O-16 | \n",
- " 3.159101 | \n",
- " 0.012939 | \n",
- "
\n",
- " \n",
- " | 5 | \n",
- " 10000 | \n",
- " 1 | \n",
- " U-235 | \n",
- " 21.095256 | \n",
- " 0.257787 | \n",
- "
\n",
- " \n",
- " | 0 | \n",
- " 10000 | \n",
- " 2 | \n",
- " U-238 | \n",
- " 11.178844 | \n",
- " 0.065428 | \n",
- "
\n",
- " \n",
- " | 1 | \n",
- " 10000 | \n",
- " 2 | \n",
- " O-16 | \n",
- " 3.800027 | \n",
- " 0.024538 | \n",
- "
\n",
- " \n",
- " | 2 | \n",
- " 10000 | \n",
- " 2 | \n",
- " U-235 | \n",
- " 485.513530 | \n",
- " 2.418761 | \n",
- "
\n",
- " \n",
- "
\n",
- "
"
- ],
- "text/plain": [
- " cell group in nuclide mean std. dev.\n",
- "3 10000 1 U-238 9.589323 0.038756\n",
- "4 10000 1 O-16 3.159101 0.012939\n",
- "5 10000 1 U-235 21.095256 0.257787\n",
- "0 10000 2 U-238 11.178844 0.065428\n",
- "1 10000 2 O-16 3.800027 0.024538\n",
- "2 10000 2 U-235 485.513530 2.418761"
- ]
- },
- "execution_count": 46,
- "metadata": {},
- "output_type": "execute_result"
- }
- ],
+ "outputs": [],
"source": [
"df = condense_xs.get_pandas_dataframe(xs_type='micro')\n",
"df"
@@ -2102,7 +1391,7 @@
},
{
"cell_type": "code",
- "execution_count": 47,
+ "execution_count": null,
"metadata": {
"collapsed": true
},
@@ -2124,7 +1413,7 @@
},
{
"cell_type": "code",
- "execution_count": 48,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -2172,7 +1461,7 @@
},
{
"cell_type": "code",
- "execution_count": 49,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -2200,21 +1489,11 @@
},
{
"cell_type": "code",
- "execution_count": 50,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "openmc keff = 1.227616\n",
- "openmoc keff = 1.225325\n",
- "bias [pcm]: -229.1\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Print report of keff and bias with OpenMC\n",
"openmoc_keff = solver.getKeff()\n",
@@ -2235,27 +1514,11 @@
},
{
"cell_type": "code",
- "execution_count": 51,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stderr",
- "output_type": "stream",
- "text": [
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n",
- "/usr/local/lib/python2.7/dist-packages/openmc-0.7.0-py2.7.egg/openmc/mgxs/mgxs.py:633: DeprecationWarning: elementwise comparison failed; this will raise the error in the future.\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"su.make_opencg_geometry()\n",
"openmoc_geometry = get_openmoc_geometry(su.opencg_geometry)\n",
@@ -2292,7 +1555,7 @@
},
{
"cell_type": "code",
- "execution_count": 52,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
@@ -2310,21 +1573,11 @@
},
{
"cell_type": "code",
- "execution_count": 53,
+ "execution_count": null,
"metadata": {
"collapsed": false
},
- "outputs": [
- {
- "name": "stdout",
- "output_type": "stream",
- "text": [
- "openmc keff = 1.227616\n",
- "openmoc keff = 1.227096\n",
- "bias [pcm]: -52.0\n"
- ]
- }
- ],
+ "outputs": [],
"source": [
"# Print report of keff and bias with OpenMC\n",
"openmoc_keff = solver.getKeff()\n",
diff --git a/openmc/mgxs/mgxs.py b/openmc/mgxs/mgxs.py
index c997381f7..579557ae8 100644
--- a/openmc/mgxs/mgxs.py
+++ b/openmc/mgxs/mgxs.py
@@ -30,7 +30,7 @@ DOMAINS = [openmc.Cell,
openmc.Material]
-class MultiGroupXS(object):
+class MGXS(object):
"""A multi-group cross section for some energy group structure within
some spatial domain.
@@ -322,7 +322,7 @@ class MultiGroupXS(object):
def create_tallies(self, scores, all_filters, keys, estimator):
"""Instantiates tallies needed to compute the multi-group cross section.
This is a helper method for MultiGroupXS subclasses to create tallies
for input file generation. The tallies are stored in the tallies dict.
This method is called by each subclass' create_tallies(...) method
which define the parameters given to this parent class method.
@@ -585,8 +585,8 @@ class MultiGroupXS(object):
Returns
-------
- MultiGroupXS
- A new MultiGroupXS condensed to the group structure of interest
+ MGXS
+ A new MGXS condensed to the group structure of interest
"""
@@ -603,7 +603,7 @@ class MultiGroupXS(object):
cv.check_value('lower coarse energy', coarse_groups.group_edges[0],
[self.energy_groups.group_edges[0]])
# Clone this MultiGroupXS to initialize the condensed version
condensed_xs = copy.deepcopy(self)
condensed_xs.energy_groups = coarse_groups
@@ -664,8 +664,8 @@ class MultiGroupXS(object):
Returns
-------
- MultiGroupXS
- A new MultiGroupXS averaged across the subdomains of interest
+ MGXS
+ A new MGXS averaged across the subdomains of interest
Raises
------
@@ -688,7 +688,7 @@ class MultiGroupXS(object):
else:
subdomains = [0]
# Clone this MultiGroupXS to initialize the subdomain-averaged version
avg_xs = copy.deepcopy(self)
avg_xs.domain_type = 'cell'
@@ -931,13 +931,13 @@ class MultiGroupXS(object):
average = average.squeeze()
std_dev = std_dev.squeeze()
# Add MultiGroupXS results data to the HDF5 group
nuclide_group.require_dataset('average', dtype=np.float64,
shape=average.shape, data=average)
nuclide_group.require_dataset('std. dev.', dtype=np.float64,
shape=std_dev.shape, data=std_dev)
- # Close the MultiGroup results HDF5 file
+ # Close the results HDF5 file
xs_results.close()
def export_xs_data(self, filename='mgxs', directory='mgxs',
@@ -1013,7 +1013,7 @@ class MultiGroupXS(object):
def get_pandas_dataframe(self, groups='all', nuclides='all',
xs_type='macro', summary=None):
"""Build a Pandas DataFrame for the MultiGroupXS data.
This method leverages the Tally.get_pandas_dataframe(...) method, but
renames the columns with terminology appropriate for cross section data.
@@ -1129,7 +1129,7 @@ class MultiGroupXS(object):
return df
-class TotalXS(MultiGroupXS):
+class TotalXS(MGXS):
"""A total multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1169,7 +1169,7 @@ class TotalXS(MultiGroupXS):
super(TotalXS, self).compute_xs()
-class TransportXS(MultiGroupXS):
+class TransportXS(MGXS):
"""A transport-corrected total multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1241,7 +1241,7 @@ class TransportXS(MultiGroupXS):
super(TransportXS, self).compute_xs()
-class AbsorptionXS(MultiGroupXS):
+class AbsorptionXS(MGXS):
"""An absorption multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1281,7 +1281,7 @@ class AbsorptionXS(MultiGroupXS):
super(AbsorptionXS, self).compute_xs()
-class CaptureXS(MultiGroupXS):
+class CaptureXS(MGXS):
"""A capture multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1321,7 +1321,7 @@ class CaptureXS(MultiGroupXS):
super(CaptureXS, self).compute_xs()
-class FissionXS(MultiGroupXS):
+class FissionXS(MGXS):
"""A fission multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1360,7 +1360,7 @@ class FissionXS(MultiGroupXS):
super(FissionXS, self).compute_xs()
-class NuFissionXS(MultiGroupXS):
+class NuFissionXS(MGXS):
"""A fission production multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1400,7 +1400,7 @@ class NuFissionXS(MultiGroupXS):
super(NuFissionXS, self).compute_xs()
-class ScatterXS(MultiGroupXS):
+class ScatterXS(MGXS):
"""A scatter multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1439,7 +1439,7 @@ class ScatterXS(MultiGroupXS):
super(ScatterXS, self).compute_xs()
-class NuScatterXS(MultiGroupXS):
+class NuScatterXS(MGXS):
"""A nu-scatter multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1479,7 +1479,7 @@ class NuScatterXS(MultiGroupXS):
super(NuScatterXS, self).compute_xs()
-class ScatterMatrixXS(MultiGroupXS):
+class ScatterMatrixXS(MGXS):
"""A scattering matrix multi-group cross section."""
def __init__(self, domain=None, domain_type=None,
@@ -1813,7 +1813,7 @@ class NuScatterMatrixXS(ScatterMatrixXS):
super(ScatterMatrixXS, self).create_tallies(scores, filters,
keys, estimator)
-class Chi(MultiGroupXS):
+class Chi(MGXS):
"""The fission spectrum."""
def __init__(self, domain=None, domain_type=None,
@@ -1883,7 +1883,7 @@ class Chi(MultiGroupXS):
return the cross section summed over all nuclides.
xs_type: {'macro', 'micro'}
This parameter is not relevant for chi but is included here to
- mirror the parent MultiGroupXS.get_xs(...) class method
+ mirror the parent MGXS.get_xs(...) class method
order_groups: {'increasing', 'decreasing'}
Return the cross section indexed according to increasing (default)
or decreasing energy groups (decreasing or increasing energies)
@@ -1995,7 +1995,7 @@ class Chi(MultiGroupXS):
def get_pandas_dataframe(self, groups='all', nuclides='all',
xs_type='macro', summary=None):
"""Build a Pandas DataFrame for the MultiGroupXS data.
This method leverages the Tally.get_pandas_dataframe(...) method, but
renames the columns with terminology appropriate for cross section data.
@@ -322,7 +322,7 @@ class MultiGroupXS(object):
def create_tallies(self, scores, all_filters, keys, estimator):
"""Instantiates tallies needed to compute the multi-group cross section.
- This is a helper method for MultiGroupXS subclasses to create tallies
+ This is a helper method for MGXS subclasses to create tallies
for input file generation. The tallies are stored in the tallies dict.
This method is called by each subclass' create_tallies(...) method
@@ -603,7 +603,7 @@ class MultiGroupXS(object):
cv.check_value('lower coarse energy', coarse_groups.group_edges[0],
[self.energy_groups.group_edges[0]])
- # Clone this MultiGroupXS to initialize the condensed version
+ # Clone this MGXS to initialize the condensed version
condensed_xs = copy.deepcopy(self)
condensed_xs.energy_groups = coarse_groups
@@ -688,7 +688,7 @@ class MultiGroupXS(object):
else:
subdomains = [0]
- # Clone this MultiGroupXS to initialize the subdomain-averaged version
+ # Clone this MGXS to initialize the subdomain-averaged version
avg_xs = copy.deepcopy(self)
avg_xs.domain_type = 'cell'
@@ -931,13 +931,13 @@ class MultiGroupXS(object):
average = average.squeeze()
std_dev = std_dev.squeeze()
- # Add MultiGroupXS results data to the HDF5 group
+ # Add MGXS results data to the HDF5 group
nuclide_group.require_dataset('average', dtype=np.float64,
shape=average.shape, data=average)
@@ -1013,7 +1013,7 @@ class MultiGroupXS(object):
def get_pandas_dataframe(self, groups='all', nuclides='all',
xs_type='macro', summary=None):
- """Build a Pandas DataFrame for the MultiGroupXS data.
+ """Build a Pandas DataFrame for the MGXS data.
This method leverages the Tally.get_pandas_dataframe(...) method, but
renames the columns with terminology appropriate for cross section data.
@@ -1995,7 +1995,7 @@ class Chi(MultiGroupXS):
def get_pandas_dataframe(self, groups='all', nuclides='all',
xs_type='macro', summary=None):
- """Build a Pandas DataFrame for the MultiGroupXS data.
+ """Build a Pandas DataFrame for the MGXS data.
This method leverages the Tally.get_pandas_dataframe(...) method, but
renames the columns with terminology appropriate for cross section data.